@@ -3,9 +3,8 @@ iso2 = getIsoscapes("CaribSr")
 
 test_that("getIsoscapes works",{
   if(!is.null(iso)){
-    expect_is(iso, "RasterStack")
+    expect_is(iso, "SpatRaster")
   }
   expect_equal(iso, iso2)
   expect_error(getIsoscapes("USPrecipALLs"))
-})
-  
\ No newline at end of file
+})
\ No newline at end of file
